import { Home } from "@mui/icons-material";
import { Grid, Button, Box, Typography } from "@mui/material";
import React from "react";
import { ReactElement, useState } from "react";

interface App {
  url?: string;
  icon?: string;
  name?: string;
  color?: string;
}

interface propsType {
  apps: App[];
  homePath: string;
}

/**
 *
 * @param {PropsType} props Component props
 * @returns {ReactElement} NerdAppsMenu
 */
export default function NerdAppsMenu(props: propsType): ReactElement {
  const { apps, homePath } = props;
  return (
    <Grid container padding="10px">
      {apps.map((app, i) => {
        return (
          <Grid key={app.name?.concat(i.toString())} item xs={4} sm={3}>
            <AppIcon app={app} />
          </Grid>
        );
      })}
      <Grid item xs={12} mt={2} textAlign={"center"}>
        <Button href={homePath} variant="outlined" startIcon={<Home />}>
          Home
        </Button>
      </Grid>
    </Grid>
  );
}

/**
 *
 * @param {object} props Component props
 * @param {App} props.app App to render
 * @returns {ReactElement} AppIcon
 */
function AppIcon(props: { app: App }): ReactElement {
  const { app } = props;
  const [hover, setHover] = useState(false);
  const transition = "ease-in";
  return (
    <Box
      sx={{
        display: "flex",
        flexDirection: "column",
        alignContent: "center",
        alignItems: "center",
        animationDelay: `-${Math.random()}s`,
        animationDuration: `.${Math.floor(Math.random() * 11) + 20}s`,
      }}
      onMouseEnter={() => setHover(true)}
      onMouseLeave={() => setHover(false)}
    >
      {app.url ? (
        <a
          href={`https://${app.url}`}
          style={{
            textDecoration: "none",
          }}
        >
          {app.icon ? (
            <img
              src={app.icon}
              alt={"app_icon"}
              width={40}
              height={40}
              style={{
                borderRadius: "20%",
                boxShadow: hover
                  ? "0 5px 18px 0 rgba(0,0,0,.3)"
                  : "0 5px 28px 0 rgba(0,0,0,.1)",
                transition: `box-shadow .2s ${transition}`,
              }}
            />
          ) : (
            <Box
              sx={{
                backgroundColor: app.color,
                marginBottom: "5px",
                width: "40px",
                height: "40px",
                textAlign: "center",
                border: `solid ${40 * 0.05}px ${app.color}`,
                background: "#424242",
                color: app.color,
                fontFamily: "Futura",
                fontSize: 40 * 0.5,
                borderTopRightRadius: 40 * 0.5,
                borderBottomLeftRadius: 40 * 0.5,
                boxShadow: hover
                  ? "0 5px 18px 0 rgba(0,0,0,.3)"
                  : "0 5px 28px 0 rgba(0,0,0,.1)",
                transition: `box-shadow .2s ${transition}`,
              }}
            >
              <Grid
                container
                justifyContent="center"
                alignItems="center"
                style={{ height: 35 }}
              >
                {app.name && <Grid item>{`${app.name[0]}${app.name[1]}`}</Grid>}
              </Grid>
            </Box>
          )}
        </a>
      ) : null}
      <Typography fontWeight={"300"} fontSize={"14px"} textAlign={"center"}>
        {app.name}
      </Typography>
    </Box>
  );
}
