import Box from "@mui/system/Box";
import React from "react";
import CorporateFareIcon from "@mui/icons-material/CorporateFare";
import CardHeader from "@mui/material/CardHeader";
import Avatar from "@mui/material/Avatar";
import LocationOnTwoToneIcon from "@mui/icons-material/LocationOnTwoTone";
import { blue, grey } from "@mui/material/colors";
import { nanoid } from "@reduxjs/toolkit";
import { AutocompleteType } from "../NerdInput/NerdInputEnums";
import Grid from "@mui/material/Grid";
import Typography from "@mui/material/Typography";
import Divider from "@mui/material/Divider";

export const RenderTemplate = ({
  props,
  option,
  autocompleteType,
  className = "",
  optionsArray = [],
  onClick,
}: {
  props?: React.HTMLAttributes<HTMLLIElement>;
  option: React.ReactNode;
  autocompleteType: AutocompleteType.CUSTOMER | AutocompleteType.ADDRESS;
  className?: string;
  optionsArray?: any[];
  onClick?: (event: React.MouseEvent<HTMLLIElement, MouseEvent>) => void;
}) => {
  const ListFoot = () => {
    return optionsArray[optionsArray.length - 1] === option ? (
      <>
        <Divider />
        <Grid container alignItems="center" justifyContent={"center"}>
          <Grid item py={1}>
            <Typography
              display={"block"}
              variant="caption"
              color="textSecondary"
            >
              Powered by <b>Google</b> and <b>Archer</b>
            </Typography>
          </Grid>
        </Grid>
      </>
    ) : null;
  };
  return (
    <React.Fragment>
      <Box
        key={nanoid()}
        component="li"
        sx={{
          backgroundColor: "transparent",
          svg: { flexShrink: 0, color: "white" },
          cursor: "pointer",
          "&:hover": {
            backgroundColor: "rgba(0, 0, 0, 0.08)",
          },
        }}
        {...props}
        className={className}
        onClick={onClick}
      >
        <CardHeader
          avatar={
            <Avatar
              sx={{
                bgcolor: setTemplateIconColorByType(autocompleteType, option),
              }}
              aria-label={autocompleteType}
            >
              {setTemplateIconByType(autocompleteType)}
            </Avatar>
          }
          title={setTemplateTitle(autocompleteType, option)}
          titleTypographyProps={{ fontWeight: "500", variant: "body1" }}
          subheader={setTemplateContentByType(autocompleteType, option)}
          sx={{
            py: 1,
            px: 1,
          }}
        />
      </Box>
      <ListFoot />
    </React.Fragment>
  );
};

/**
 *
 * @param type
 */
function setTemplateIconByType(type: string) {
  switch (type) {
    case AutocompleteType.CUSTOMER:
      return <CorporateFareIcon fontSize="medium" />;
    case AutocompleteType.ADDRESS:
      return <LocationOnTwoToneIcon fontSize="medium" />;
    default:
      return <CorporateFareIcon fontSize="medium" />;
  }
}

/**
 *
 * @param type
 * @param option
 */
function setTemplateIconColorByType(type: string, option: any) {
  switch (type) {
    case AutocompleteType.CUSTOMER:
      return blue[500];
    case AutocompleteType.ADDRESS:
      if (option.name) {
        return blue[500];
      }
      return grey[500];
    default:
      return blue[500];
  }
}

/**
 *
 * @param type
 * @param option
 */
function setTemplateContentByType(type: string, option: any) {
  const auxContentCredit = option.credit_on_hold ? " - ( Credit Hold )" : "";
  const auxContentInactivity = option.inactivity_hold
    ? " - ( Inactivity Hold )"
    : "";
  switch (type) {
    case AutocompleteType.CUSTOMER:
      return `${option.line1} ${option.state} ${option.zip} ${auxContentCredit} ${auxContentInactivity}`;
    case AutocompleteType.ADDRESS:
      if (option.structured_formatting) {
        return `${option.structured_formatting.secondary_text}`;
      }
      return option.name;
    default:
      return "";
  }
}

/**
 *
 * @param type
 * @param option
 */
function setTemplateTitle(type: string, option: any) {
  switch (type) {
    case AutocompleteType.CUSTOMER:
      return `${option.name}`;
    case AutocompleteType.ADDRESS:
      if (option.structured_formatting) {
        return `${option.structured_formatting.main_text}`;
      }
      return option.name;
    default:
      return "";
  }
}
