import React from "react";
import Typography, { TypographyProps } from "@mui/material/Typography";
import Grid from "@mui/material/Grid";
import NerdHeadingIcon from "./NerdHeadingIcon";
import { NerdHeadingProps } from "../typings";
import { ConditionalWrapper } from "../../utility/ConditionalWrapper";

export const NerdHeadingComposed: React.FC<
  NerdHeadingProps & TypographyProps
> = (props) => {
  const {
    text,
    display,
    variant,
    classes,
    icon,
    color,
    children,
    iconPosition = "left",
    spacing = 1,
    alignItems = "center",
    uppercase,
    ...rest
  } = props;
  return (
    <ConditionalWrapper
      condition={
        (text !== "" || typeof children === "string") && icon !== undefined
      }
      wrapper={(childrenContent: JSX.Element) => (
        <Grid container spacing={spacing} alignItems={alignItems}>
          {childrenContent}
        </Grid>
      )}
    >
      <React.Fragment>
        {icon && <NerdHeadingIcon {...{ icon, color, iconPosition }} />}
        {typeof children === "object" && (
          <NerdHeadingIcon icon={children} {...{ color, iconPosition }} />
        )}
        {(typeof children === "string" || text) && (
          <Grid item>
            <Typography
              display={display}
              variant={variant}
              classes={classes}
              color={color}
              textTransform={uppercase ? "uppercase" : undefined}
              {...rest}
            >
              {typeof children === "string" ? children : text}
            </Typography>
          </Grid>
        )}
      </React.Fragment>
    </ConditionalWrapper>
  );
};
