import React, { useRef } from "react";
import Popover from "@mui/material/Popover";
import { NerdHeading } from "../NerdHeading";
import { INerdHelpProps } from "./typings";
import { styled } from "@mui/system";
import Box from "@mui/material/Box";

export const NerdHelp = ({
  explanation,
  classes,
  children,
  anchorOrigin = {
    vertical: "top",
    horizontal: "left",
  },
  transformOrigin = {
    vertical: "bottom",
    horizontal: "left",
  },
  variant = "body1",
}: INerdHelpProps) => {
  const [anchorEl, setAnchorEl] = React.useState(null);
  const htmlRef = useRef(null);
  const open = Boolean(anchorEl);

  const onMouseEnter = () => {
    setAnchorEl(htmlRef.current);
  };

  const onMouseLeave = () => {
    setAnchorEl(null);
  };

  return (
    <React.Fragment>
      <Box
        ref={htmlRef}
        onMouseEnter={onMouseEnter}
        onMouseLeave={onMouseLeave}
      >
        {children}
      </Box>
      <StyledPopover
        sx={{
          pointerEvents: "none",
        }}
        open={open}
        anchorEl={anchorEl}
        anchorOrigin={anchorOrigin}
        transformOrigin={transformOrigin}
        classes={{
          ...classes,
        }}
      >
        <NerdHeading variant={variant} text={explanation} sx={{ p: 1 }} />
      </StyledPopover>
    </React.Fragment>
  );
};

const StyledPopover = styled(Popover, {
  name: "StyledPopover",
  slot: "Wrapper",
})(() => ({
  width: "100%",
}));
