import React, { SyntheticEvent, useState } from "react";
import Grid from "@mui/material/Grid";
import { ConditionalWrapper } from "../utility/ConditionalWrapper";
import IconButton from "@mui/material/IconButton";
import CloseIcon from "@mui/icons-material/Close";
import { NerdDate } from "./NerdDate/NerdDate";
import { NerdText } from "./NerdText/NerdText";
import { NerdPassword } from "./NerdPassword/NerdPassword";

export const NerdInput = ({ type = "text", ...props }: any) => {
  const [close, setClose] = useState(false);
  const {
    icon,
    spacing = 1,
    disabled,
    fullWidth,
    alignItems = "center",
    inputSize = 6,
    onChange,
  } = props;

  const sizeWithIcons = fullWidth ? 11 : inputSize;
  const customInputSize = fullWidth && !icon ? 12 : sizeWithIcons;
  return (
    <ConditionalWrapper
      condition={icon !== undefined}
      wrapper={(childrenContent: JSX.Element) => (
        <Grid container spacing={spacing} alignItems={alignItems}>
          {childrenContent}
        </Grid>
      )}
    >
      <React.Fragment>
        {icon && <Grid item>{icon}</Grid>}
        <Grid item sm={customInputSize} xs={icon ? 9 : 12}>
          {renderNerdInputByType({ type, props, close, setClose, onChange })}
        </Grid>
        {icon && (
          <Grid item>
            <IconButton
              disabled={disabled}
              size="small"
              onClick={() => setClose(true)}
            >
              <CloseIcon />
            </IconButton>
          </Grid>
        )}
      </React.Fragment>
    </ConditionalWrapper>
  );
};

/**
 * @param auxProps
 * @param auxProps.type
 * @param auxProps.props
 * @param auxProps.close
 * @param auxProps.setClose
 * @param auxProps.onChange
 */
function renderNerdInputByType(auxProps: {
  type: string;
  props: any;
  close: boolean;
  onChange: (event: SyntheticEvent<Element, Event>) => void;
  setClose: (close: boolean) => void;
}): JSX.Element {
  const { type, props } = auxProps;

  switch (type) {
    case "date":
      return <NerdDate {...props} />;
    case "text":
      return <NerdText {...props} />;
    case "password":
      return <NerdPassword {...props} />;
    default:
      return <NerdText {...props} />;
  }
}
