import { Checkbox, FormControlLabel, FormGroup } from "@mui/material";
import { GridFilterInputValueProps } from "@mui/x-data-grid-pro";
import React from "react";

/**
 * DataGrid boolean filter input.
 *
 * @param {GridFilterInputValueProps} props Component props
 * @returns {React.ReactElement} CheckBox input for boolean type filter.
 */
export default function BoolOperatorInput(
  props: GridFilterInputValueProps
): React.ReactElement {
  const { item, applyValue, focusElementRef } = props;

  const ref: React.Ref<HTMLDivElement> = React.useRef(null);
  React.useImperativeHandle(focusElementRef, () => ({
    focus: () => {
      (
        ref?.current?.querySelector(
          `input[value="${item.value || ""}"]`
        ) as HTMLElement
      )?.focus();
    },
  }));

  const handleFilterChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    applyValue({ ...item, value: event.target.checked });
  };

  return (
    <FormGroup sx={{ justifyContent: "center" }}>
      <FormControlLabel
        control={
          <Checkbox
            name="custom-filter-operator"
            placeholder="Value"
            checked={item.value || false}
            onChange={(e) => handleFilterChange(e)}
          />
        }
        label="Active"
      />
    </FormGroup>
  );
}
