import { TextField } from "@mui/material";
import { GridFilterInputValueProps } from "@mui/x-data-grid-pro";
import React from "react";
import { AdapterMoment } from "@mui/x-date-pickers/AdapterMoment";
import { LocalizationProvider } from "@mui/x-date-pickers/LocalizationProvider";
import { DatePicker } from "@mui/x-date-pickers/DatePicker";
import moment from "moment";

/**
 * DataGrid date filter input.
 *
 * @param {GridFilterInputValueProps} props Component props
 * @returns {React.ReactElement} DatePicker input for date type filter.
 */
export default function DateOperatorInput(
  props: GridFilterInputValueProps
): React.ReactElement {
  const { item, applyValue, focusElementRef } = props;

  const ref: React.Ref<HTMLDivElement> = React.useRef(null);
  React.useImperativeHandle(focusElementRef, () => ({
    focus: () => {
      (
        ref?.current?.querySelector(
          `input[value="${item.value || ""}"]`
        ) as HTMLElement
      )?.focus();
    },
  }));

  const handleFilterChange = (value: moment.Moment) => {
    applyValue({ ...item, value: value ? value.format("YYYY-MM-DD") : "" });
  };

  return (
    <LocalizationProvider dateAdapter={AdapterMoment}>
      <DatePicker
        inputFormat="YYYY/MM/DD"
        mask="____/__/__"
        label="Value"
        value={item.value || ""}
        onChange={(value) => handleFilterChange(value)}
        ref={ref}
        renderInput={(params) => (
          <TextField
            {...params}
            placeholder="Value"
            label="Value"
            variant="standard"
          />
        )}
      />
    </LocalizationProvider>
  );
}
