import React from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import {
  findIconDefinition,
  IconDefinition,
  IconLookup,
  IconName,
  library,
} from "@fortawesome/fontawesome-svg-core";
import { fas } from "@fortawesome/free-solid-svg-icons";
import Box from "@mui/material/Box";

type FontAwesomeSvgIconProps = {
  icon: string | IconDefinition;
  severity?: string;
  iconColor?: string;
};

library.add(fas);

const NerdFontAwesomeIcon = React.forwardRef<
  SVGSVGElement,
  FontAwesomeSvgIconProps
>((props: FontAwesomeSvgIconProps, ref) => {
  const { icon, severity, iconColor } = props;

  if (!icon) {
    return null;
  }

  return (
    <Box mt={2} mx={"auto"} ref={ref}>
      {typeof icon === "string" ? (
        setCustomIconString({ icon, severity, iconColor })
      ) : (
        <FontAwesomeIcon icon={icon} size="3x" color={iconColor ?? "#0288d1"} />
      )}
    </Box>
  );
});

NerdFontAwesomeIcon.displayName = "NerdFontAwesomeIcon";

export { NerdFontAwesomeIcon };

/**
 * @param {object} root0 props
 * @param {string} root0.icon Icon
 * @param {string} root0.iconColor Icon color
 * @param {string} root0.severity Severity
 * @returns {JSX.Element} Custom Icon String
 */
function setCustomIconString({
  icon,
  iconColor,
  severity,
}: {
  icon: string;
  iconColor?: string;
  severity?: string;
}): JSX.Element {
  return (
    <FontAwesomeIcon
      icon={setCustomIconDefinition(icon as IconName)}
      color={
        iconColor && iconColor !== ""
          ? iconColor
          : colorSwitch(severity || "info")
      }
      size="3x"
    />
  );
}

/**
 * @param {IconName} icon Icon
 * @returns {IconDefinition} Custom Icon definition
 */
export function setCustomIconDefinition(icon: IconName): IconDefinition {
  const iconLookup: IconLookup = {
    prefix: "fas",
    iconName: icon,
  };
  const customIconDefinition: IconDefinition = findIconDefinition(iconLookup);

  return customIconDefinition;
}

export const colorSwitch = (color: string) =>
  ({
    error: "#d32f2f",
    info: "#0288d1",
    success: "#2e7d32",
    warning: "#ed6c02",
  }[color]);
